@@ -4,11 +4,12 @@ import (
 	"errors"
 	"io/ioutil"
 	"os"
+	"strconv"
 	"strings"
 
 	"github.com/mitchellh/go-homedir"
-	. "github.com/onsi/ginkgo"
-	. "github.com/onsi/ginkgo/extensions/table"
+
+	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 	g "github.com/onsi/gomega/gstruct"
 	"github.com/onsi/gomega/types"
@@ -70,6 +71,7 @@ var _ = Describe("Cli", func() {
 		}
 		ctx = c.Context{}
 
+		http.MockTickerSymbols()
 		http.MockResponseCurrency()
 		//nolint:errcheck
 		dep.Fs.MkdirAll("./", 0755)
@@ -99,7 +101,7 @@ var _ = Describe("Cli", func() {
 				output := getStdout(func() {
 					Run(inputStartFn)(&cobra.Command{}, []string{})
 				})
-				Expect(output).To(Equal("Unable to start UI: ui error\n"))
+				Expect(output).To(Equal("unable to start UI: ui error\n"))
 				Expect(fnIsCalled).To(Equal(true))
 			})
 		})
@@ -239,6 +241,41 @@ var _ = Describe("Cli", func() {
 					}),
 				}),
 
+				// symbols by source
+				Entry("when groups and watchlist are defined", Case{
+					InputOptions: cli.Options{},
+					InputConfigFileContents: strings.Join([]string{
+						"watchlist:",
+						"  - TSLA",        // yahoo finance
+						"  - ETHEREUM.CG", // coingecko
+						"  - SOL.X",       // ticker
+					}, "\n"),
+					AssertionErr: BeNil(),
+					AssertionCtx: g.MatchFields(g.IgnoreExtras, g.Fields{
+						"Groups": g.MatchAllElementsWithIndex(g.IndexIdentity, g.Elements{
+							"0": g.MatchFields(g.IgnoreExtras, g.Fields{
+								"SymbolsBySource": g.MatchAllElements(func(element interface{}) string {
+									return strconv.FormatInt(int64(element.(c.AssetGroupSymbolsBySource).Source), 10)
+								}, g.Elements{
+									"0": g.MatchFields(g.IgnoreExtras, g.Fields{
+										"Symbols": g.MatchAllElementsWithIndex(g.IndexIdentity, g.Elements{
+											"0": Equal("TSLA"),
+										}),
+										"Source": Equal(c.QuoteSourceYahoo),
+									}),
+									"2": g.MatchFields(g.IgnoreExtras, g.Fields{
+										"Symbols": g.MatchAllElementsWithIndex(g.IndexIdentity, g.Elements{
+											"0": Equal("ethereum"),
+											"1": Equal("solana"),
+										}),
+										"Source": Equal(c.QuoteSourceCoingecko),
+									}),
+								}),
+							}),
+						}),
+					}),
+				}),
+
 				// option: string (proxy, sort)
 				Entry("when proxy is set in config file", Case{
 					InputOptions:            cli.Options{},
@@ -352,6 +389,35 @@ var _ = Describe("Cli", func() {
 					}),
 				}),
 			)
+
+			When("there is an error getting ticker symbols", func() {
+
+				It("returns the error", func() {
+
+					http.MockTickerSymbolsError()
+
+					_, outputErr := GetContext(dep, cli.Options{}, "")
+
+					Expect(outputErr).ToNot(BeNil())
+
+				})
+
+			})
+
+			When("there is an error getting reference data", func() {
+
+				PIt("returns the error", func() {
+
+					http.MockResponseCurrencyError()
+
+					_, outputErr := GetContext(dep, cli.Options{}, "")
+
+					Expect(outputErr).ToNot(BeNil())
+
+				})
+
+			})
+
 		})
 
 		//nolint:errcheck
@@ -440,7 +506,7 @@ var _ = Describe("Cli", func() {
 					outputCtx, outputErr := GetContext(depLocal, cli.Options{}, inputConfigPath)
 
 					Expect(outputCtx.Config).To(Equal(c.Config{}))
-					Expect(outputErr).To(MatchError("Invalid config: open .config-file-that-does-not-exist.yaml: file does not exist"))
+					Expect(outputErr).To(MatchError("invalid config: open .config-file-that-does-not-exist.yaml: file does not exist"))
 				})
 			})
 
@@ -451,7 +517,7 @@ var _ = Describe("Cli", func() {
 					outputCtx, outputErr := GetContext(depLocal, cli.Options{}, inputConfigPath)
 
 					Expect(outputCtx.Config).To(Equal(c.Config{}))
-					Expect(outputErr).To(MatchError("Invalid config: yaml: unmarshal errors:\n  line 2: cannot unmarshal !!str `NOK` into []string"))
+					Expect(outputErr).To(MatchError("invalid config: yaml: unmarshal errors:\n  line 2: cannot unmarshal !!str `NOK` into []string"))
 
 				})
 			})
@@ -473,7 +539,7 @@ var _ = Describe("Cli", func() {
 				It("should return an error", func() {
 					options.Watchlist = ""
 					outputErr := Validate(&ctx, &options, nil)(&cobra.Command{}, []string{})
-					Expect(outputErr).To(MatchError("Invalid config: No watchlist provided"))
+					Expect(outputErr).To(MatchError("invalid config: No watchlist provided"))
 				})
 
 				When("a nil error reference is passed in from Cobra", func() {
