@@ -5,7 +5,7 @@ import (
 	"strings"
 
 	"github.com/acarl005/stripansi"
-	. "github.com/onsi/ginkgo"
+	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 
 	c "github.com/achannarasappa/ticker/internal/common"
